@@ -74,6 +74,12 @@ namespace Rcpp {
     template<typename out_eT, typename T1, typename T2, typename glue_type>
     SEXP wrap( const arma::mtGlue<out_eT,T1,T2,glue_type>& X );
     
+    template <typename eT, typename gen_type>
+    SEXP wrap( const arma::Gen<eT,gen_type>& X) ;
+    
+    template<typename eT, typename gen_type>
+    SEXP wrap( const arma::GenCube<eT,gen_type>& X) ;
+    
     namespace traits {
 
 	/* support for as */
