@@ -98,6 +98,16 @@
   #define arma_ctrsyl ctrsyl
   #define arma_ztrsyl ztrsyl
   
+  #define arma_ssytrf ssytrf
+  #define arma_dsytrf dsytrf
+  #define arma_csytrf csytrf
+  #define arma_zsytrf zsytrf
+  
+  #define arma_ssytri ssytri
+  #define arma_dsytri dsytri
+  #define arma_csytri csytri
+  #define arma_zsytri zsytri
+  
 #else
   
   #define arma_sgetrf SGETRF
@@ -179,6 +189,16 @@
   #define arma_ctrsyl CTRSYL
   #define arma_ztrsyl ZTRSYL
   
+  #define arma_ssytrf SSYTRF
+  #define arma_dsytrf DSYTRF
+  #define arma_csytrf CSYTRF
+  #define arma_zsytrf ZSYTRF
+  
+  #define arma_ssytri SSYTRI
+  #define arma_dsytri DSYTRI
+  #define arma_csytri CSYTRI
+  #define arma_zsytri ZSYTRI
+  
 #endif
 
 
@@ -291,6 +311,16 @@ namespace lapack
     void arma_fortran(arma_ctrsyl)(char* transa, char* transb, blas_int* isgn, blas_int* m, blas_int* n, const void*   a, blas_int* lda, const void*   b, blas_int* ldb, void*   c, blas_int* ldc, float*  scale, blas_int* info);
     void arma_fortran(arma_ztrsyl)(char* transa, char* transb, blas_int* isgn, blas_int* m, blas_int* n, const void*   a, blas_int* lda, const void*   b, blas_int* ldb, void*   c, blas_int* ldc, double* scale, blas_int* info);
     
+    void arma_fortran(arma_ssytrf)(char* uplo, blas_int* n, float*  a, blas_int* lda, blas_int* ipiv, float*  work, blas_int* lwork, blas_int* info);
+    void arma_fortran(arma_dsytrf)(char* uplo, blas_int* n, double* a, blas_int* lda, blas_int* ipiv, double* work, blas_int* lwork, blas_int* info);
+    void arma_fortran(arma_csytrf)(char* uplo, blas_int* n, void*   a, blas_int* lda, blas_int* ipiv, void*   work, blas_int* lwork, blas_int* info);
+    void arma_fortran(arma_zsytrf)(char* uplo, blas_int* n, void*   a, blas_int* lda, blas_int* ipiv, void*   work, blas_int* lwork, blas_int* info);
+    
+    void arma_fortran(arma_ssytri)(char* uplo, blas_int* n, float*  a, blas_int* lda, blas_int* ipiv, float*  work, blas_int* info);
+    void arma_fortran(arma_dsytri)(char* uplo, blas_int* n, double* a, blas_int* lda, blas_int* ipiv, double* work, blas_int* info);
+    void arma_fortran(arma_csytri)(char* uplo, blas_int* n, void*   a, blas_int* lda, blas_int* ipiv, void*   work, blas_int* info);
+    void arma_fortran(arma_zsytri)(char* uplo, blas_int* n, void*   a, blas_int* lda, blas_int* ipiv, void*   work, blas_int* info);
+    
     // void arma_fortran(arma_dgeqp3)(blas_int* m, blas_int* n, double* a, blas_int* lda, blas_int* jpvt, double* tau, double* work, blas_int* lwork, blas_int* info);
     // void arma_fortran(arma_dormqr)(char* side, char* trans, blas_int* m, blas_int* n, blas_int* k, double* a, blas_int* lda, double* tau, double* c, blas_int* ldc, double* work, blas_int* lwork, blas_int* info);
     // void  arma_fortran(arma_dposv)(char* uplo, blas_int* n, blas_int* nrhs, double* a, blas_int* lda, double* b, blas_int* ldb, blas_int* info);
@@ -303,7 +333,7 @@ namespace lapack
   void
   getrf(blas_int* m, blas_int* n, eT* a, blas_int* lda, blas_int* ipiv, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -337,7 +367,7 @@ namespace lapack
   void
   getri(blas_int* n,  eT* a, blas_int* lda, blas_int* ipiv, eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -371,7 +401,7 @@ namespace lapack
   void
   trtri(char* uplo, char* diag, blas_int* n, eT* a, blas_int* lda, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -405,7 +435,7 @@ namespace lapack
   void
   syev(char* jobz, char* uplo, blas_int* n, eT* a, blas_int* lda, eT* w,  eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -433,7 +463,7 @@ namespace lapack
     blas_int* info
     )
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_supported_complex_float<eT>::value == true)
       {
@@ -463,7 +493,7 @@ namespace lapack
     blas_int* info
     )
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
 
     if(is_float<eT>::value == true)
       {
@@ -492,7 +522,7 @@ namespace lapack
     blas_int* info
     )
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_supported_complex_float<eT>::value == true)
       {
@@ -517,7 +547,7 @@ namespace lapack
   void
   potrf(char* uplo, blas_int* n, eT* a, blas_int* lda, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -552,7 +582,7 @@ namespace lapack
   void
   potri(char* uplo, blas_int* n, eT* a, blas_int* lda, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -587,7 +617,7 @@ namespace lapack
   void
   geqrf(blas_int* m, blas_int* n, eT* a, blas_int* lda, eT* tau, eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -622,7 +652,7 @@ namespace lapack
   void
   orgqr(blas_int* m, blas_int* n, blas_int* k, eT* a, blas_int* lda, eT* tau, eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -644,7 +674,7 @@ namespace lapack
   void
   ungqr(blas_int* m, blas_int* n, blas_int* k, eT* a, blas_int* lda, eT* tau, eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_supported_complex_float<eT>::value == true)
       {
@@ -670,7 +700,7 @@ namespace lapack
     eT* work, blas_int* lwork, blas_int* info
     )
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -697,8 +727,8 @@ namespace lapack
     std::complex<T>* work, blas_int* lwork, T* rwork, blas_int* info
     )
     {
-    arma_type_check<is_supported_blas_type<T>::value == false>::apply();
-    arma_type_check<is_supported_blas_type< std::complex<T> >::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<T>::value == false ));
+    arma_type_check(( is_supported_blas_type< std::complex<T> >::value == false ));
     
     if(is_float<T>::value == true)
       {
@@ -730,7 +760,7 @@ namespace lapack
   void
   gesv(blas_int* n, blas_int* nrhs, eT* a, blas_int* lda, blas_int* ipiv, eT* b, blas_int* ldb, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -764,7 +794,7 @@ namespace lapack
   void
   gels(char* trans, blas_int* m, blas_int* n, blas_int* nrhs, eT* a, blas_int* lda, eT* b, blas_int* ldb, eT* work, blas_int* lwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -798,7 +828,7 @@ namespace lapack
   void
   trtrs(char* uplo, char* trans, char* diag, blas_int* n, blas_int* nrhs, const eT* a, blas_int* lda, eT* b, blas_int* ldb, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -832,7 +862,7 @@ namespace lapack
   void
   gees(char* jobvs, char* sort, blas_int* select, blas_int* n, eT* a, blas_int* lda, blas_int* sdim, eT* wr, eT* wi, eT* vs, blas_int* ldvs, eT* work, blas_int* lwork, blas_int* bwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -854,8 +884,8 @@ namespace lapack
   void
   cx_gees(char* jobvs, char* sort, blas_int* select, blas_int* n, std::complex<T>* a, blas_int* lda, blas_int* sdim, std::complex<T>* w, std::complex<T>* vs, blas_int* ldvs, std::complex<T>* work, blas_int* lwork, T* rwork, blas_int* bwork, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<T>::value == false>::apply();
-    arma_type_check<is_supported_blas_type< std::complex<T> >::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<T>::value == false ));
+    arma_type_check(( is_supported_blas_type< std::complex<T> >::value == false ));
     
     if(is_float<T>::value == true)
       {
@@ -879,7 +909,7 @@ namespace lapack
   void
   trsyl(char* transa, char* transb, blas_int* isgn, blas_int* m, blas_int* n, const eT* a, blas_int* lda, const eT* b, blas_int* ldb, eT* c, blas_int* ldc, eT* scale, blas_int* info)
     {
-    arma_type_check<is_supported_blas_type<eT>::value == false>::apply();
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
     
     if(is_float<eT>::value == true)
       {
@@ -907,6 +937,71 @@ namespace lapack
     }
   
   
+  template<typename eT>
+  inline
+  void
+  sytrf(char* uplo, blas_int* n, eT* a, blas_int* lda, blas_int* ipiv, eT* work, blas_int* lwork, blas_int* info)
+    {
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
+    
+    if(is_float<eT>::value == true)
+      {
+      typedef float T;
+      arma_fortran(arma_ssytrf)(uplo, n, (T*)a, lda, ipiv, (T*)work, lwork, info);
+      }
+    else
+    if(is_double<eT>::value == true)
+      {
+      typedef double T;
+      arma_fortran(arma_dsytrf)(uplo, n, (T*)a, lda, ipiv, (T*)work, lwork, info);
+      }
+    else
+    if(is_supported_complex_float<eT>::value == true)
+      {
+      typedef std::complex<float> T;
+      arma_fortran(arma_csytrf)(uplo, n, (T*)a, lda, ipiv, (T*)work, lwork, info);
+      }
+    else
+    if(is_supported_complex_double<eT>::value == true)
+      {
+      typedef std::complex<double> T;
+      arma_fortran(arma_zsytrf)(uplo, n, (T*)a, lda, ipiv, (T*)work, lwork, info);
+      }
+    }
+  
+  
+  template<typename eT>
+  inline
+  void
+  sytri(char* uplo, blas_int* n, eT* a, blas_int* lda, blas_int* ipiv, eT* work, blas_int* info)
+    {
+    arma_type_check(( is_supported_blas_type<eT>::value == false ));
+    
+    if(is_float<eT>::value == true)
+      {
+      typedef float T;
+      arma_fortran(arma_ssytri)(uplo, n, (T*)a, lda, ipiv, (T*)work, info);
+      }
+    else
+    if(is_double<eT>::value == true)
+      {
+      typedef double T;
+      arma_fortran(arma_dsytri)(uplo, n, (T*)a, lda, ipiv, (T*)work, info);
+      }
+    else
+    if(is_supported_complex_float<eT>::value == true)
+      {
+      typedef std::complex<float> T;
+      arma_fortran(arma_csytri)(uplo, n, (T*)a, lda, ipiv, (T*)work, info);
+      }
+    else
+    if(is_supported_complex_double<eT>::value == true)
+      {
+      typedef std::complex<double> T;
+      arma_fortran(arma_zsytri)(uplo, n, (T*)a, lda, ipiv, (T*)work, info);
+      }
+    }
+  
   
   //! @}
   }
