@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -25,12 +25,12 @@ class mtGlueCube : public BaseCube<out_eT, mtGlueCube<out_eT, T1, T2, glue_type>
   typedef typename get_pod_type<out_eT>::result pod_type;
   
   arma_inline  mtGlueCube(const T1& in_A, const T2& in_B);
-  arma_inline  mtGlueCube(const T1& in_A, const T2& in_B, const u32 in_aux_u32);
+  arma_inline  mtGlueCube(const T1& in_A, const T2& in_B, const uword in_aux_uword);
   arma_inline ~mtGlueCube();
   
-  arma_aligned const T1& A;       //!< first operand
-  arma_aligned const T2& B;       //!< second operand
-  arma_aligned const u32 aux_u32; //!< storage of auxiliary data, u32 format
+  arma_aligned const T1& A;           //!< first operand
+  arma_aligned const T2& B;           //!< second operand
+  arma_aligned       uword aux_uword; //!< storage of auxiliary data, uword format
   };
 
 
